| cs_cov | R Documentation |
Computing the Cubic spline covariance function for a single distance measure.
cs_cov(dists, sigsq, phi)
dists |
a numeric matrix representing the distance between spatial entities. |
sigsq |
the σ^2 parameter from the Spherical covariance. function. |
phi |
the φ parameter from the Spherical covariance function, controls the range of the spatial dependence. ' |
The Spherical covariance function (for a stationary and
isotropic process) associated with the provided distances (dists)
and the given set of parameters.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.