| gw_cov | R Documentation |
Computing the Matern covariance function for a matrix of distances.
gw_cov(dists, sigsq, phi, kappa, mu)
dists |
a numeric matrix representing the distance between spatial entities. |
sigsq |
the σ^2 parameter from the Matern covariance function. |
phi |
φ is the range of the covariance function. |
kappa |
κ \in \{0, …, 3 \}. |
mu |
μ controls the smoothness of the covariance function |
The GW (isotropic) covariance function associated with the provided
distances (dists) and the given set of parameters.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.