spm_fitProvides a data.frame with point estimates and
confidence intervals for the parameters of the model fitted using the
spm_fit function.
summary_spm_fit(x, sig = 0.05)a data.frame summarizing the parameters estimated by the
fit_spm function.
a spm_fit object.
a real number between 0 and 1 indicating significance level to be used to compute the confidence intervals for the parameter estimates.