| tapmat_cov | R Documentation |
Computing the tappered Matern covariance function for a matrix of distances.
tapmat_cov(dists, sigsq, phi, nu, theta)
dists |
a numeric matrix representing the distance between spatial entities. |
sigsq |
the σ^2 parameter from the Matern covariance function. |
phi |
the φ parameter from the Matern covariance function,' |
nu |
smoothness parameter |
theta |
θ taper range. |
The tappered matern covariance function (for a stationary and isotropic
process) associated with the provided distances (dists) and the
given set of parameters.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.