Computing the Matern covariance function for a matrix of distances.
Computing the Matern covariance function between polygons.
mat_cov(dists, sigsq, phi, nu)comp_mat_cov(cross_dists, n, n2, sigsq, phi, nu)
pexp_cov(dists, sigsq, phi, nu)
comp_pexp_cov(cross_dists, n, n2, sigsq, phi, nu)
gauss_cov(dists, sigsq, phi)
comp_gauss_cov(cross_dists, n, n2, sigsq, phi)
spher_cov(dists, sigsq, phi)
comp_spher_cov(cross_dists, n, n2, sigsq, phi)
cs_cov(dists, sigsq, phi)
comp_cs_cov(cross_dists, n, n2, sigsq, phi)
gw_cov(dists, sigsq, phi, kappa, mu)
comp_gw_cov(cross_dists, n, n2, sigsq, phi, kappa, mu)
The matern covariance function (for a stationary and isotropic
process) associated with the provided distances (dists) and the
given set of parameters.
The matern covariance matrix associated with a set of polygons.
a numeric matrix representing the distance between spatial entities.
the \(\sigma^2\) parameter from the Matern covariance function.
the \(\phi\) parameter from the Matern covariance function, controls the range of the spatial dependence.
the \(\nu\) parameter from the Matern covariance function, controls the differentiability of the process.
a list such that each position contains the cross
distances between points within different polygons.
single_exp, single_matern
single_exp, single_matern,
mat_cov