adapted from Bevilacqua et al. 2019.
single_gw0(d, sigsq, phi, mu)single_gw1(d, sigsq, phi, mu)
single_gw2(d, sigsq, phi, mu)
single_gw3(d, sigsq, phi, mu)
single_gw(d, sigsq, phi, kappa, mu)
a scalar representing the GW covariance between two
observations d apart of each other.
a scalar representing the distance on which it is desired to evaluate the covariance function.
the \(\sigma^2\) parameter from the Matern covariance function.
the \(\phi\) parameter from the Matern covariance function, controls the range of the spatial dependence.
a parameter that controls the smoothness of the covariance function. Note that, \(\mu \geq 1\).
\(\kappa \in \{0, \ldots, 3 \}\).