vor_build: Voronoi Tessellation inside a polygon
Description
voronoi tessellation of a given a set of points inside a
polygon. This is an internal use function.
Usage
vor_build(points_sf, poly_sf)
Value
a sf object containing the polygons associated with the
voronoi tessellation of points_sf the polygon poly_sf
Arguments
- points_sf
sf data frame containing the points' coordinates
- poly_sf
a sf polygon